@@ -48,9 +48,9 @@ if (!isGeneric("postSamples")) {
     setGeneric("postSamples", function(object) standardGeneric("postSamples"))
 }
 
-    
+
 
 if (!isGeneric("rnlp")) {
-  setGeneric("rnlp", function(y, x, m, V, msfit, priorCoef, priorVar=igprior(alpha=0.01,lambda=0.01), niter=10^3, burnin=round(niter/10), thinning=1, pp='norm') standardGeneric("rnlp"))
+  setGeneric("rnlp", function(y, x, m, V, msfit, priorCoef, priorVar, niter=10^3, burnin=round(niter/10), thinning=1, pp='norm') standardGeneric("rnlp"))
 }
 
